export const description =
  '在此页面中，我们将看到一些由我们杰出的成员贡献的社区资源，以帮助开发者快速入门使用 Robyn。'

## 演讲

- [EuroPython 2022](https://www.youtube.com/watch?v=AutugvJNVkY&)
- [GeoPython 2022](https://www.youtube.com/watch?v=YCpbCQwbkd4)
- [PyCon US 2022](https://youtu.be/1IiL31tUEVk?t=2101)
- [PyCon Sweden 2021](https://www.youtube.com/watch?v=DK9teAs72Do)

## 博客

- [Hello, Robyn!](https://www.sanskar.me/posts/hello-robyn)

## 下一步

现在，蝙蝠侠对它充满兴趣

- [托管](/documentation/zh/hosting)
